==> cms-db_v0.5.1.tar.gz: admin/delete.php <==
<?php
/*  cms-db  Copyright (C) 2007-2008 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('pages');
?>
<?php
function moveToRecycleBin($file) {
	$file_exploded= explode('/', $file);
	$newfile = $file_exploded[count($file_exploded) - 1];
	if ($newfile == '01,Home') {
		$newfile = $file_exploded[count($file_exploded) - 2];
	}
	$newfile = substr($newfile, 3);
	$newfile = '../data/recyclebin/pages/'.$newfile;
	if (file_exists($newfile)) {
		$timestamp = time();
		$newfile = $newfile.'-'.$timestamp;
	}
	copy($file, $newfile);
	unlink($file);
}
function delFiles($ordner) {
	$handle = opendir($ordner);
	while (false !== ($file = readdir($handle))) {
		if($file != "." && $file != "..") {
			if(is_dir($ordner."/".$file)) {
				delFiles($ordner."/".$file);
				rmdir($ordner."/".$file);
			} else {
				moveToRecycleBin($ordner.'/'.$file);
			}
		}
	}
}
if (is_dir($_GET['file'])) {
	delFiles($_GET['file']);
	rmdir($_GET['file']);
} else {
	moveToRecycleBin($_GET['file']);
}

$handle = opendir($_GET["dir"]);
while (false !== ($file = readdir($handle))) {
	if($file != "." && $file != "..") {
		$array[] = $file;
	}
}
natcasesort($array);
$count = 00;
foreach ($array as $file) {
	$count++;
	if ($count < 10) {
		$newcount = '0'.$count;
	} else {
		$newcount = $count;
	}
	$new = $newcount.','.substr($file,3);
	rename($_GET["dir"]."/".$file,$_GET["dir"]."/".$new);
}
header("Location:pages.php?show=delete&".SID);
?>

==> cms-db_v0.6.tar.gz: admin/delete.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('pages');

function moveToRecycleBin($file) {
	$file_exploded= explode('/', $file);
	$newfile = $file_exploded[count($file_exploded) - 1];
	if ($newfile == '01,Home') {
		$newfile = $file_exploded[count($file_exploded) - 2];
	}
	$newfile = substr($newfile, 3);
	$newfile = '../data/recyclebin/pages/'.$newfile;
	if (file_exists($newfile)) {
		$i = 2;
		while (file_exists($newfile.' ('.$i.')')) {
			$i++;
		}
		$newfile = $newfile.' ('.$i.')';
	}
	copy($file, $newfile);
	unlink($file);
}
function delFiles($ordner) {
	$handle = opendir($ordner);
	while (false !== ($file = readdir($handle))) {
		if($file != "." && $file != "..") {
			if(is_dir($ordner."/".$file)) {
				delFiles($ordner."/".$file);
				rmdir($ordner."/".$file);
			} else {
				moveToRecycleBin($ordner.'/'.$file);
			}
		}
	}
}

include('../functions_url.inc.php');
$file = get_filename_from_url($_GET['file']);
$file = '../data/pages'.substr($file, 0, strrpos($file, '/'));

delFiles($file);
rmdir($file);

$dir = substr($file, 0, strrpos($file, '/'));

$handle = opendir($dir);
while (false !== ($file = readdir($handle))) {
	if($file != "." && $file != "..") {
		$array[] = $file;
	}
}
natcasesort($array);
$count = 00;
foreach ($array as $file) {
	$count++;
	if ($count < 10) {
		$newcount = '0'.$count;
	} else {
		$newcount = $count;
	}
	$new = $newcount.','.substr($file,3);
	rename($dir.'/'.$file, $dir.'/'.$new);
}
include('urlindex.inc.php');
generate_urlindex();
header("Location:pages.php?show=delete&".SID);
?>
